#[repr(C)]pub enum hv_error_t {
HV_SUCCESS = 0,
HV_ERROR = 4_209_590_273,
HV_BUSY = 4_209_590_274,
HV_BAD_ARGUMENT = 4_209_590_275,
HV_ILLEGAL_GUEST_STATE = 4_209_590_276,
HV_NO_RESOURCES = 4_209_590_277,
HV_NO_DEVICE = 4_209_590_278,
HV_DENIED = 4_209_590_279,
HV_FAULT = 4_209_590_280,
HV_UNSUPPORTED = 4_209_590_287,
}Expand description
Errors returned by Hypervisor functions.
Variants
HV_SUCCESS = 0
The operation completed successfully.
HV_ERROR = 4_209_590_273
The operation was unsuccessful.
HV_BUSY = 4_209_590_274
The operation was unsuccessful because the owning resource was busy.
HV_BAD_ARGUMENT = 4_209_590_275
The operation was unsuccessful because the function call had an invalid argument.
HV_ILLEGAL_GUEST_STATE = 4_209_590_276
The operation was unsuccessful because the guest is in an illegal state.
HV_NO_RESOURCES = 4_209_590_277
The operation was unsuccessful because the host had no resources available to complete the request.
HV_NO_DEVICE = 4_209_590_278
The operation was unsuccessful because no VM or vCPU was available.
HV_DENIED = 4_209_590_279
The system didn’t allow the requested operation.
HV_FAULT = 4_209_590_280
HV_FAULT
HV_UNSUPPORTED = 4_209_590_287
The operation requested isn’t supported by the hypervisor.