#[repr(C)]pub enum hv_exit_reason_t {
CANCELED = 0,
EXCEPTION = 1,
VTIMER_ACTIVATED = 2,
UNKNOWN = 3,
}Expand description
The type that describes the event that triggered a guest exit to the host.
Variants
CANCELED = 0
The value that identifies exits requested by exit handler on the host.
EXCEPTION = 1
The value that identifies traps caused by the guest operations.
VTIMER_ACTIVATED = 2
The value that identifies when the virtual timer enters the pending state.
UNKNOWN = 3
The value that identifies unexpected exits.