hv_sys_reg_t

Enum hv_sys_reg_t 

#[repr(C)]
pub enum hv_sys_reg_t {
Show 148 variants DBGBVR0_EL1 = 32_772, DBGBCR0_EL1 = 32_773, DBGWVR0_EL1 = 32_774, DBGWCR0_EL1 = 32_775, DBGBVR1_EL1 = 32_780, DBGBCR1_EL1 = 32_781, DBGWVR1_EL1 = 32_782, DBGWCR1_EL1 = 32_783, MDCCINT_EL1 = 32_784, MDSCR_EL1 = 32_786, DBGBVR2_EL1 = 32_788, DBGBCR2_EL1 = 32_789, DBGWVR2_EL1 = 32_790, DBGWCR2_EL1 = 32_791, DBGBVR3_EL1 = 32_796, DBGBCR3_EL1 = 32_797, DBGWVR3_EL1 = 32_798, DBGWCR3_EL1 = 32_799, DBGBVR4_EL1 = 32_804, DBGBCR4_EL1 = 32_805, DBGWVR4_EL1 = 32_806, DBGWCR4_EL1 = 32_807, DBGBVR5_EL1 = 32_812, DBGBCR5_EL1 = 32_813, DBGWVR5_EL1 = 32_814, DBGWCR5_EL1 = 32_815, DBGBVR6_EL1 = 32_820, DBGBCR6_EL1 = 32_821, DBGWVR6_EL1 = 32_822, DBGWCR6_EL1 = 32_823, DBGBVR7_EL1 = 32_828, DBGBCR7_EL1 = 32_829, DBGWVR7_EL1 = 32_830, DBGWCR7_EL1 = 32_831, DBGBVR8_EL1 = 32_836, DBGBCR8_EL1 = 32_837, DBGWVR8_EL1 = 32_838, DBGWCR8_EL1 = 32_839, DBGBVR9_EL1 = 32_844, DBGBCR9_EL1 = 32_845, DBGWVR9_EL1 = 32_846, DBGWCR9_EL1 = 32_847, DBGBVR10_EL1 = 32_852, DBGBCR10_EL1 = 32_853, DBGWVR10_EL1 = 32_854, DBGWCR10_EL1 = 32_855, DBGBVR11_EL1 = 32_860, DBGBCR11_EL1 = 32_861, DBGWVR11_EL1 = 32_862, DBGWCR11_EL1 = 32_863, DBGBVR12_EL1 = 32_868, DBGBCR12_EL1 = 32_869, DBGWVR12_EL1 = 32_870, DBGWCR12_EL1 = 32_871, DBGBVR13_EL1 = 32_876, DBGBCR13_EL1 = 32_877, DBGWVR13_EL1 = 32_878, DBGWCR13_EL1 = 32_879, DBGBVR14_EL1 = 32_884, DBGBCR14_EL1 = 32_885, DBGWVR14_EL1 = 32_886, DBGWCR14_EL1 = 32_887, DBGBVR15_EL1 = 32_892, DBGBCR15_EL1 = 32_893, DBGWVR15_EL1 = 32_894, DBGWCR15_EL1 = 32_895, MIDR_EL1 = 49_152, MPIDR_EL1 = 49_157, ID_AA64PFR0_EL1 = 49_184, ID_AA64PFR1_EL1 = 49_185, ID_AA64ZFR0_EL1 = 49_188, ID_AA64SMFR0_EL1 = 49_189, ID_AA64DFR0_EL1 = 49_192, ID_AA64DFR1_EL1 = 49_193, ID_AA64ISAR0_EL1 = 49_200, ID_AA64ISAR1_EL1 = 49_201, ID_AA64MMFR0_EL1 = 49_208, ID_AA64MMFR1_EL1 = 49_209, ID_AA64MMFR2_EL1 = 49_210, SCTLR_EL1 = 49_280, CPACR_EL1 = 49_282, ACTLR_EL1 = 49_281, SMPRI_EL1 = 49_300, SMCR_EL1 = 49_302, TTBR0_EL1 = 49_408, TTBR1_EL1 = 49_409, TCR_EL1 = 49_410, APIAKEYLO_EL1 = 49_416, APIAKEYHI_EL1 = 49_417, APIBKEYLO_EL1 = 49_418, APIBKEYHI_EL1 = 49_419, APDAKEYLO_EL1 = 49_424, APDAKEYHI_EL1 = 49_425, APDBKEYLO_EL1 = 49_426, APDBKEYHI_EL1 = 49_427, APGAKEYLO_EL1 = 49_432, APGAKEYHI_EL1 = 49_433, SPSR_EL1 = 49_664, ELR_EL1 = 49_665, SP_EL0 = 49_672, AFSR0_EL1 = 49_800, AFSR1_EL1 = 49_801, ESR_EL1 = 49_808, FAR_EL1 = 49_920, PAR_EL1 = 50_080, MAIR_EL1 = 50_448, AMAIR_EL1 = 50_456, VBAR_EL1 = 50_688, CONTEXTIDR_EL1 = 50_817, TPIDR_EL1 = 50_820, SCXTNUM_EL1 = 50_823, CNTKCTL_EL1 = 50_952, CSSELR_EL1 = 53_248, TPIDR_EL0 = 56_962, TPIDRRO_EL0 = 56_963, TPIDR2_EL0 = 56_965, SCXTNUM_EL0 = 56_967, CNTV_CTL_EL0 = 57_113, CNTV_CVAL_EL0 = 57_114, SP_EL1 = 57_864, CNTP_CTL_EL0 = 57_105, CNTP_CVAL_EL0 = 57_106, CNTP_TVAL_EL0 = 57_104, CNTHCTL_EL2 = 59_144, CNTHP_CTL_EL2 = 59_153, CNTHP_CVAL_EL2 = 59_154, CNTHP_TVAL_EL2 = 59_152, CNTVOFF_EL2 = 59_139, CPTR_EL2 = 57_482, ELR_EL2 = 57_857, ESR_EL2 = 58_000, FAR_EL2 = 58_112, HCR_EL2 = 57_480, HPFAR_EL2 = 58_116, MAIR_EL2 = 58_640, MDCR_EL2 = 57_369, SCTLR_EL2 = 57_472, SPSR_EL2 = 57_856, SP_EL2 = 61_960, TCR_EL2 = 57_602, TPIDR_EL2 = 59_010, TTBR0_EL2 = 57_600, TTBR1_EL2 = 57_601, VBAR_EL2 = 58_880, VMPIDR_EL2 = 57_349, VPIDR_EL2 = 57_344, VTCR_EL2 = 57_610, VTTBR_EL2 = 57_608,
}
The type of system registers.

Variants



DBGBVR0_EL1 = 32_772

The value that represents the system register DBGBVR0_EL1.



DBGBCR0_EL1 = 32_773

The value that represents the system register DBGBCR0_EL1.



DBGWVR0_EL1 = 32_774

The value that represents the system register DBGWVR0_EL1.



DBGWCR0_EL1 = 32_775

The value that represents the system register DBGWCR0_EL1.



DBGBVR1_EL1 = 32_780

The value that represents the system register DBGBVR1_EL1.



DBGBCR1_EL1 = 32_781

The value that represents the system register DBGBCR1_EL1.



DBGWVR1_EL1 = 32_782

The value that represents the system register DBGWVR1_EL1.



DBGWCR1_EL1 = 32_783

The value that represents the system register DBGWCR1_EL1.



MDCCINT_EL1 = 32_784

The value that represents the system register MDCCINT_EL1.



MDSCR_EL1 = 32_786

The value that represents the system register MDSCR_EL1.



DBGBVR2_EL1 = 32_788

The value that represents the system register DBGBVR2_EL1.



DBGBCR2_EL1 = 32_789

The value that represents the system register DBGBCR2_EL1.



DBGWVR2_EL1 = 32_790

The value that represents the system register DBGWVR2_EL1.



DBGWCR2_EL1 = 32_791

The value that represents the system register DBGWCR2_EL1.



DBGBVR3_EL1 = 32_796

The value that represents the system register DBGBVR3_EL1.



DBGBCR3_EL1 = 32_797

The value that represents the system register DBGBCR3_EL1.



DBGWVR3_EL1 = 32_798

The value that represents the system register DBGWVR3_EL1.



DBGWCR3_EL1 = 32_799

The value that represents the system register DBGWCR3_EL1.



DBGBVR4_EL1 = 32_804

The value that represents the system register DBGBVR4_EL1.



DBGBCR4_EL1 = 32_805

The value that represents the system register DBGBCR4_EL1.



DBGWVR4_EL1 = 32_806

The value that represents the system register DBGWVR4_EL1.



DBGWCR4_EL1 = 32_807

The value that represents the system register DBGWCR4_EL1.



DBGBVR5_EL1 = 32_812

The value that represents the system register DBGBVR5_EL1.



DBGBCR5_EL1 = 32_813

The value that represents the system register DBGBCR5_EL1.



DBGWVR5_EL1 = 32_814

The value that represents the system register DBGWVR5_EL1.



DBGWCR5_EL1 = 32_815

The value that represents the system register DBGWCR5_EL1.



DBGBVR6_EL1 = 32_820

The value that represents the system register DBGBVR6_EL1.



DBGBCR6_EL1 = 32_821

The value that represents the system register DBGBCR6_EL1.



DBGWVR6_EL1 = 32_822

The value that represents the system register DBGWVR6_EL1.



DBGWCR6_EL1 = 32_823

The value that represents the system register DBGWCR6_EL1.



DBGBVR7_EL1 = 32_828

The value that represents the system register DBGBVR7_EL1.



DBGBCR7_EL1 = 32_829

The value that represents the system register DBGBCR7_EL1.



DBGWVR7_EL1 = 32_830

The value that represents the system register DBGWVR7_EL1.



DBGWCR7_EL1 = 32_831

The value that represents the system register DBGWCR7_EL1.



DBGBVR8_EL1 = 32_836

The value that represents the system register DBGBVR8_EL1.



DBGBCR8_EL1 = 32_837

The value that represents the system register DBGBCR8_EL1.



DBGWVR8_EL1 = 32_838

The value that represents the system register DBGWVR8_EL1.



DBGWCR8_EL1 = 32_839

The value that represents the system register DBGWCR8_EL1.



DBGBVR9_EL1 = 32_844

The value that represents the system register DBGBVR9_EL1.



DBGBCR9_EL1 = 32_845

The value that represents the system register DBGBCR9_EL1.



DBGWVR9_EL1 = 32_846

The value that represents the system register DBGWVR9_EL1.



DBGWCR9_EL1 = 32_847

The value that represents the system register DBGWCR9_EL1.



DBGBVR10_EL1 = 32_852

The value that represents the system register DBGBVR10_EL1.



DBGBCR10_EL1 = 32_853

The value that represents the system register DBGBCR10_EL1.



DBGWVR10_EL1 = 32_854

The value that represents the system register DBGWVR10_EL1.



DBGWCR10_EL1 = 32_855

The value that represents the system register DBGWCR10_EL1.



DBGBVR11_EL1 = 32_860

The value that represents the system register DBGBVR11_EL1.



DBGBCR11_EL1 = 32_861

The value that represents the system register DBGBCR11_EL1.



DBGWVR11_EL1 = 32_862

The value that represents the system register DBGWVR11_EL1.



DBGWCR11_EL1 = 32_863

The value that represents the system register DBGWCR11_EL1.



DBGBVR12_EL1 = 32_868

The value that represents the system register DBGBVR12_EL1.



DBGBCR12_EL1 = 32_869

The value that represents the system register DBGBCR12_EL1.



DBGWVR12_EL1 = 32_870

The value that represents the system register DBGWVR12_EL1.



DBGWCR12_EL1 = 32_871

The value that represents the system register DBGWCR12_EL1.



DBGBVR13_EL1 = 32_876

The value that represents the system register DBGBVR13_EL1.



DBGBCR13_EL1 = 32_877

The value that represents the system register DBGBCR13_EL1.



DBGWVR13_EL1 = 32_878

The value that represents the system register DBGWVR13_EL1.



DBGWCR13_EL1 = 32_879

The value that represents the system register DBGWCR13_EL1.



DBGBVR14_EL1 = 32_884

The value that represents the system register DBGBVR14_EL1.



DBGBCR14_EL1 = 32_885

The value that represents the system register DBGBCR14_EL1.



DBGWVR14_EL1 = 32_886

The value that represents the system register DBGWVR14_EL1.



DBGWCR14_EL1 = 32_887

The value that represents the system register DBGWCR14_EL1.



DBGBVR15_EL1 = 32_892

The value that represents the system register DBGBVR15_EL1.



DBGBCR15_EL1 = 32_893

The value that represents the system register DBGBCR15_EL1.



DBGWVR15_EL1 = 32_894

The value that represents the system register DBGWVR15_EL1.



DBGWCR15_EL1 = 32_895

The value that represents the system register DBGWCR15_EL1.



MIDR_EL1 = 49_152

The value that represents the system register MIDR_EL1.



MPIDR_EL1 = 49_157

The value that represents the system register MPIDR_EL1.



ID_AA64PFR0_EL1 = 49_184

The value that describes the AArch64 Processor Feature Register 0.



ID_AA64PFR1_EL1 = 49_185

The value that describes the AArch64 Processor Feature Register 1.



ID_AA64ZFR0_EL1 = 49_188

The value that describes the AArch64 SVE Feature ID register 0.



ID_AA64SMFR0_EL1 = 49_189

The value that describes the AArch64 SME Feature ID register 0.



ID_AA64DFR0_EL1 = 49_192

The value that describes the AArch64 Debug Feature Register 0.



ID_AA64DFR1_EL1 = 49_193

The value that describes the AArch64 Debug Feature Register 1.



ID_AA64ISAR0_EL1 = 49_200

The value that describes the AArch64 Instruction Set Attribute Register 0.



ID_AA64ISAR1_EL1 = 49_201

The value that describes the AArch64 Instruction Set Attribute Register 1.



ID_AA64MMFR0_EL1 = 49_208

The value that describes the AArch64 Memory Model Feature Register 0.



ID_AA64MMFR1_EL1 = 49_209

The value that describes the AArch64 Memory Model Feature Register 1.



ID_AA64MMFR2_EL1 = 49_210

The value that describes the AArch64 Memory Model Feature Register 2.



SCTLR_EL1 = 49_280

The value that represents the system register SCTLR_EL1.



CPACR_EL1 = 49_282

The value that represents the system register CPACR_EL1.



ACTLR_EL1 = 49_281

The value that represents the system register ACTLR_EL1.

This only allows getting / setting of the ACTLR_EL1.EnTSO bit (index 1). Setting this bit to 1 will cause the vcpu to use a TSO memory model, whereas clearing it will cause the vcpu to use the default ARM64 memory model (weakly ordered loads / stores).



SMPRI_EL1 = 49_300

The value that describes the Streaming Mode Priority Register.



SMCR_EL1 = 49_302

The value that describes the SME Control Register.



TTBR0_EL1 = 49_408

The value that represents the system register TTBR0_EL1.



TTBR1_EL1 = 49_409

The value that represents the system register TTBR1_EL1.



TCR_EL1 = 49_410

The value that represents the system register TCR_EL1.



APIAKEYLO_EL1 = 49_416

The value that represents the system register APIAKEYLO_EL1.



APIAKEYHI_EL1 = 49_417

The value that represents the system register APIAKEYHI_EL1.



APIBKEYLO_EL1 = 49_418

The value that represents the system register APIBKEYLO_EL1.



APIBKEYHI_EL1 = 49_419

The value that represents the system register APIBKEYHI_EL1.



APDAKEYLO_EL1 = 49_424

The value that represents the system register APDAKEYLO_EL1.



APDAKEYHI_EL1 = 49_425

The value that represents the system register APDAKEYHI_EL1.



APDBKEYLO_EL1 = 49_426

The value that represents the system register APDBKEYLO_EL1.



APDBKEYHI_EL1 = 49_427

The value that represents the system register APDBKEYHI_EL1.



APGAKEYLO_EL1 = 49_432

The value that represents the system register APGAKEYLO_EL1.



APGAKEYHI_EL1 = 49_433

The value that represents the system register APGAKEYHI_EL1.



SPSR_EL1 = 49_664

The value that represents the system register SPSR_EL1.



ELR_EL1 = 49_665

The value that represents the system register ELR_EL1.



SP_EL0 = 49_672

The value that represents the system register SP_EL0.



AFSR0_EL1 = 49_800

The value that represents the system register AFSR0_EL1.



AFSR1_EL1 = 49_801

The value that represents the system register AFSR1_EL1.



ESR_EL1 = 49_808

The value that represents the system register ESR_EL1.



FAR_EL1 = 49_920

The value that represents the system register FAR_EL1.



PAR_EL1 = 50_080

The value that represents the system register PAR_EL1.



MAIR_EL1 = 50_448

The value that represents the system register MAIR_EL1.



AMAIR_EL1 = 50_456

The value that represents the system register AMAIR_EL1.



VBAR_EL1 = 50_688

The value that represents the system register VBAR_EL1.



CONTEXTIDR_EL1 = 50_817

The value that represents the system register CONTEXTIDR_EL1.



TPIDR_EL1 = 50_820

The value that represents the system register TPIDR_EL1.



SCXTNUM_EL1 = 50_823

The value that represents the system register SCXTNUM_EL1.



CNTKCTL_EL1 = 50_952

The value that represents the system register CNTKCTL_EL1.



CSSELR_EL1 = 53_248

The value that represents the system register CSSELR_EL1.



TPIDR_EL0 = 56_962

The value that represents the system register TPIDR_EL0.



TPIDRRO_EL0 = 56_963

The value that represents the system register TPIDRRO_EL0.



TPIDR2_EL0 = 56_965

The value that represents the system register TPIDR2_EL0.



SCXTNUM_EL0 = 56_967

The value that represents the system register SCXTNUM_EL0.



CNTV_CTL_EL0 = 57_113

The value that represents the system register CNTV_CTL_EL0.



CNTV_CVAL_EL0 = 57_114

The value that represents the system register CNTV_CVAL_EL0.



SP_EL1 = 57_864

The value that represents the system register SP_EL1.



CNTP_CTL_EL0 = 57_105

The value that represents the system register CNTP_CTL_EL0. This register is only available if EL2 was enabled in the VM configuration.



CNTP_CVAL_EL0 = 57_106

The value that represents the system register CNTP_CVAL_EL0. This register is only available if EL2 was enabled in the VM configuration.



CNTP_TVAL_EL0 = 57_104

The value that represents the system register CNTP_TVAL_EL0. This register is only available if EL2 was enabled in the VM configuration.



CNTHCTL_EL2 = 59_144

The value that represents the system register CNTHCTL_EL2. This register is only available if EL2 was enabled in the VM configuration.



CNTHP_CTL_EL2 = 59_153

The value that represents the system register CNTHP_CTL_EL2. This register is only available if EL2 was enabled in the VM configuration.



CNTHP_CVAL_EL2 = 59_154

The value that represents the system register CNTHP_CVAL_EL2. This register is only available if EL2 was enabled in the VM configuration.



CNTHP_TVAL_EL2 = 59_152

The value that represents the system register CNTHP_TVAL_EL2. This register is only available if EL2 was enabled in the VM configuration.



CNTVOFF_EL2 = 59_139

The value that represents the system register CNTVOFF_EL2. This register is only available if EL2 was enabled in the VM configuration.



CPTR_EL2 = 57_482

The value that represents the system register CPTR_EL2. This register is only available if EL2 was enabled in the VM configuration.



ELR_EL2 = 57_857

The value that represents the system register ELR_EL2. This register is only available if EL2 was enabled in the VM configuration.



ESR_EL2 = 58_000

The value that represents the system register ESR_EL2. This register is only available if EL2 was enabled in the VM configuration.



FAR_EL2 = 58_112

The value that represents the system register FAR_EL2. This register is only available if EL2 was enabled in the VM configuration.



HCR_EL2 = 57_480

The value that represents the system register HCR_EL2. This register is only available if EL2 was enabled in the VM configuration.



HPFAR_EL2 = 58_116

The value that represents the system register HPFAR_EL2. This register is only available if EL2 was enabled in the VM configuration.



MAIR_EL2 = 58_640

The value that represents the system register MAIR_EL2. This register is only available if EL2 was enabled in the VM configuration.



MDCR_EL2 = 57_369

The value that represents the system register MDCR_EL2. This register is only available if EL2 was enabled in the VM configuration.



SCTLR_EL2 = 57_472

The value that represents the system register SCTLR_EL2. This register is only available if EL2 was enabled in the VM configuration.



SPSR_EL2 = 57_856

The value that represents the system register SPSR_EL2. This register is only available if EL2 was enabled in the VM configuration.



SP_EL2 = 61_960

The value that represents the system register SP_EL2. This register is only available if EL2 was enabled in the VM configuration.



TCR_EL2 = 57_602

The value that represents the system register TCR_EL2. This register is only available if EL2 was enabled in the VM configuration.



TPIDR_EL2 = 59_010

The value that represents the system register TPIDR_EL2. This register is only available if EL2 was enabled in the VM configuration.



TTBR0_EL2 = 57_600

The value that represents the system register TTBR0_EL2. This register is only available if EL2 was enabled in the VM configuration.



TTBR1_EL2 = 57_601

The value that represents the system register TTBR1_EL2. This register is only available if EL2 was enabled in the VM configuration.



VBAR_EL2 = 58_880

The value that represents the system register VBAR_EL2. This register is only available if EL2 was enabled in the VM configuration.



VMPIDR_EL2 = 57_349

The value that represents the system register VMPIDR_EL2. This register is only available if EL2 was enabled in the VM configuration.



VPIDR_EL2 = 57_344

The value that represents the system register VPIDR_EL2. This register is only available if EL2 was enabled in the VM configuration.



VTCR_EL2 = 57_610

The value that represents the system register VTCR_EL2. This register is only available if EL2 was enabled in the VM configuration.



VTTBR_EL2 = 57_608

The value that represents the system register VTTBR_EL2. This register is only available if EL2 was enabled in the VM configuration.