hv_vcpu_get_trap_debug_exceptions

Function hv_vcpu_get_trap_debug_exceptions 

pub unsafe extern "C" fn hv_vcpu_get_trap_debug_exceptions(
    vcpu: hv_vcpu_t,
    value: *mut bool,
) -> hv_return_t
Gets whether debug exceptions exit the guest.

Parameters

  • vcpu: The vCPU instance.
  • value: Indicates whether debug exceptions in the guest trap to the host on output.

Return Value

HV_SUCCESS if the operation was successful, otherwise an error code specified in hv_return_t.