hv_vcpu_set_trap_debug_exceptions

Function hv_vcpu_set_trap_debug_exceptions 

pub unsafe extern "C" fn hv_vcpu_set_trap_debug_exceptions(
    vcpu: hv_vcpu_t,
    value: bool,
) -> hv_return_t
Sets whether debug exceptions exit the guest.

Parameters

  • vcpu: The vCPU instance.
  • value: A Boolean value that if true indicates debug exceptions in the guest trap to the host.

Return Value

HV_SUCCESS if the operation was successful, otherwise an error code specified in hv_return_t.