#[repr(C)]pub struct hv_vcpu_exit_t {
pub reason: hv_exit_reason_t,
pub exception: hv_vcpu_exit_exception_t,
}Expand description
Information about an exit from the vCPU to the host.
Fields
reason: hv_exit_reason_tInformation about an exit from the vcpu to the host.
exception: hv_vcpu_exit_exception_tInformation about an exit exception from the vcpu to the host.