#[repr(C)]
pub enum hv_error_t {
    HV_SUCCESS,
    HV_ERROR,
    HV_BUSY,
    HV_BAD_ARGUMENT,
    HV_ILLEGAL_GUEST_STATE,
    HV_NO_RESOURCES,
    HV_NO_DEVICE,
    HV_DENIED,
    HV_FAULT,
    HV_UNSUPPORTED,
}
Errors returned by Hypervisor functions.

Variants

HV_SUCCESS

The operation completed successfully.

HV_ERROR

The operation was unsuccessful.

HV_BUSY

The operation was unsuccessful because the owning resource was busy.

HV_BAD_ARGUMENT

The operation was unsuccessful because the function call had an invalid argument.

HV_ILLEGAL_GUEST_STATE

The operation was unsuccessful because the guest is in an illegal state.

HV_NO_RESOURCES

The operation was unsuccessful because the host had no resources available to complete the request.

HV_NO_DEVICE

The operation was unsuccessful because no VM or vCPU was available.

HV_DENIED

The system didn’t allow the requested operation.

HV_FAULT

HV_FAULT

HV_UNSUPPORTED

The operation requested isn’t supported by the hypervisor.