pub unsafe extern "C" fn hv_vm_map(
addr: *const c_void,
ipa: hv_ipa_t,
size: usize,
flags: hv_memory_flags_t,
) -> hv_return_tExpand description
Maps a region in the virtual address space of the current process into the guest physical address space of the VM.
Parameters
addr: The address in the current process. It must be page-aligned.ipa: The address in the intermediate physical address space. It must be page-aligned.size: The size of the mapped region in bytes. It must be a multiple of the page size.flags: The permissions for the mapped region. For a list of valid options, seehv_memory_flags_t.
Return Value
HV_SUCCESS if the operation was successful, otherwise an error code specified in
hv_return_t.